@@ -5,9 +5,6 @@ use warnings;
 
 use Data::Dumper;
 
-use FindBin; # only for this example - load local Udev::FFI module
-use lib "$FindBin::Bin/../lib"; # only for this example - load local Udev::FFI module
-
 use Udev::FFI;
 
 
