@@ -4,6 +4,7 @@ use strict;
 use warnings;
 
 use Udev::FFI::Functions qw(:all);
+use Udev::FFI::Helper;
 
 
 
@@ -104,7 +105,7 @@ sub get_parent {
     my $self = shift;
 
     my $device = udev_device_get_parent( $self->{_device} );
-    if(defined($device)) {
+    if (defined($device)) {
         udev_device_ref($device);
 
         return Udev::FFI::Device->new($device, $self->{_udev});
@@ -120,7 +121,7 @@ sub get_parent_with_subsystem_devtype {
     my $devtype = shift;
 
     my $device = udev_device_get_parent_with_subsystem_devtype( $self->{_device}, $subsystem, $devtype );
-    if(defined($device)) {
+    if (defined($device)) {
         udev_device_ref($device);
 
         return Udev::FFI::Device->new($device, $self->{_udev});
@@ -131,19 +132,19 @@ sub get_parent_with_subsystem_devtype {
 
 
 sub get_devlinks_list_entries {
-    return get_entries( udev_device_get_devlinks_list_entry( $_[0]->{_device} ) );
+    return Udev::FFI::Helper::get_entries_all( udev_device_get_devlinks_list_entry( $_[0]->{_device} ) );
 }
 
 sub get_properties_list_entries {
-    return get_entries( udev_device_get_properties_list_entry( $_[0]->{_device} ) );
+    return Udev::FFI::Helper::get_entries_all( udev_device_get_properties_list_entry( $_[0]->{_device} ) );
 }
 
 sub get_tags_list_entries {
-    return get_entries( udev_device_get_tags_list_entry( $_[0]->{_device} ) );
+    return Udev::FFI::Helper::get_entries_all( udev_device_get_tags_list_entry( $_[0]->{_device} ) );
 }
 
 sub get_sysattr_list_entries {
-    return get_entries( udev_device_get_sysattr_list_entry( $_[0]->{_device} ) );
+    return Udev::FFI::Helper::get_entries_all( udev_device_get_sysattr_list_entry( $_[0]->{_device} ) );
 }
 
 
@@ -171,16 +172,16 @@ Udev::FFI::Device
     use Udev::FFI;
     
     my $udev = Udev::FFI->new() or
-        die "Can't create Udev::FFI object: $@";
+        die("Can't create Udev::FFI object: $@");
     
     my $device = $udev->new_device_from_subsystem_sysname('block', 'sda1');
-    if(defined($device)) {
+    if (defined($device)) {
         print "SYSPATH: ".$device->get_syspath()."\n";
 
-        if(my $fs = $device->get_property_value('ID_FS_TYPE')) {
+        if (my $fs = $device->get_property_value('ID_FS_TYPE')) {
             print "FS: $fs\n";
         }
-        if(my $uuid = $device->get_property_value('ID_FS_UUID')) {
+        if (my $uuid = $device->get_property_value('ID_FS_UUID')) {
             print "UUID: $uuid\n";
         }
     }
